@@ -57,11 +57,11 @@ var ImageDialog = {
                         f0.caption.checked = true;
                     }
                 } else if ((classnames[i] == 'image-inline') ||
-                           (classnames[i] == 'image-styleA') ||
-                           (classnames[i] == 'image-styleB') ||
-                           (classnames[i] == 'image-styleC') ||
-                           (classnames[i] == 'image-left') ||
-                           (classnames[i] == 'image-right')) {
+                           (classnames[i] == 'image-left')   ||
+                           (classnames[i] == 'image-right')  ||
+                           (classnames[i] == 'image-inline-styleA') ||
+                           (classnames[i] == 'image-left-styleB')   ||
+                           (classnames[i] == 'image-right-styleC')) {
                     classname = classnames[i];
                 } else {
                     ImageDialog.current_class = classnames[i];
